@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2012 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,6 +32,21 @@
 
 #include <QAbstractTableModel>
 #include <QTime>
+#include <QVector>
+
+namespace GammaRay {
+
+struct DebugMessage {
+  QtMsgType type;
+  QString message;
+  QTime time;
+  Backtrace backtrace;
+};
+
+}
+
+Q_DECLARE_METATYPE(GammaRay::DebugMessage)
+Q_DECLARE_TYPEINFO(GammaRay::DebugMessage, Q_MOVABLE_TYPE);
 
 namespace GammaRay {
 
@@ -35,13 +55,13 @@ class MessageModel : public QAbstractTableModel
   Q_OBJECT
   public:
     explicit MessageModel(QObject *parent = 0);
-    virtual ~MessageModel();
+    ~MessageModel();
 
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    virtual int columnCount(const QModelIndex &parent = QModelIndex()) const;
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
-    virtual QVariant headerData(int section, Qt::Orientation orientation,
-                                int role = Qt::DisplayRole) const;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    QVariant headerData(int section, Qt::Orientation orientation,
+                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
 
     enum Columns {
       TypeColumn,
@@ -50,18 +70,11 @@ class MessageModel : public QAbstractTableModel
       COLUMN_COUNT
     };
 
-    struct Message {
-      QtMsgType type;
-      QString message;
-      QTime time;
-      Backtrace backtrace;
-    };
-
   public slots:
-    void addMessage(const MessageModel::Message &message);
+    void addMessage(const GammaRay::DebugMessage &message);
 
   private:
-    QList<Message> m_messages;
+    QVector<DebugMessage> m_messages;
 };
 
 }
