@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2012 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -24,28 +29,26 @@
 #ifndef GAMMARAY_METAOBJECTBROWSER_METATYPEBROWSER_H
 #define GAMMARAY_METAOBJECTBROWSER_METATYPEBROWSER_H
 
-#include "include/toolfactory.h"
+#include "toolfactory.h"
 
-#include <QWidget>
-
-class QModelIndex;
+class QItemSelection;
 
 namespace GammaRay {
 
-class PropertyWidget;
+class PropertyController;
 
-class MetaObjectBrowser : public QWidget
+class MetaObjectBrowser : public QObject
 {
   Q_OBJECT
 
   public:
-    explicit MetaObjectBrowser(ProbeInterface *probe, QWidget *parent = 0);
+    explicit MetaObjectBrowser(ProbeInterface *probe, QObject *parent = 0);
 
   private Q_SLOTS:
-    void objectSelected(const QModelIndex& index);
+    void objectSelected(const QItemSelection &selection);
 
   private:
-     PropertyWidget* m_propertyWidget;
+     PropertyController *m_propertyController;
 };
 
 class MetaObjectBrowserFactory : public QObject,
