@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2012 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -22,23 +27,16 @@
 */
 
 #include "metatypebrowser.h"
-#include "ui_metatypebrowser.h"
-
 #include "metatypesmodel.h"
 
+#include "common/objectbroker.h"
+
 using namespace GammaRay;
 
-MetaTypeBrowser::MetaTypeBrowser(ProbeInterface *probe, QWidget *parent)
-  : QWidget(parent),
-    ui(new Ui::MetaTypeBrowser)
+MetaTypeBrowser::MetaTypeBrowser(ProbeInterface *probe, QObject *parent)
+  : QObject(parent)
 {
-  Q_UNUSED(probe);
-  ui->setupUi(this);
-
   MetaTypesModel *mtm = new MetaTypesModel(this);
-  ui->metaTypeView->setModel(mtm);
-  ui->metaTypeView->setRootIsDecorated(false);
-  ui->metaTypeView->header()->setResizeMode(0, QHeaderView::ResizeToContents);
+  probe->registerModel("com.kdab.GammaRay.MetaTypeModel", mtm);
 }
 
-#include "metatypebrowser.moc"
