@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2012 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -24,16 +29,33 @@
 #ifndef GAMMARAY_PROBEFINDER_H
 #define GAMMARAY_PROBEFINDER_H
 
+#include <QVector>
+
 class QString;
+class QStringList;
 
 namespace GammaRay {
 
+class ProbeABI;
+
 namespace ProbeFinder {
 
   /**
    * Attempts to find the full path of the probe DLL.
    */
-  QString findProbe(const QString &baseName);
+  QString findProbe(const QString& baseName, const ProbeABI& probeAbi);
+
+  /**
+   * Find the best matching probe for the given @p targetABI.
+   * An invalid ProbeABI instance is returned if there is no compatible probe installed.
+   */
+  ProbeABI findBestMatchingABI(const ProbeABI &targetABI);
+  ProbeABI findBestMatchingABI(const ProbeABI &targetABI, const QVector<ProbeABI> &availableABIs);
+
+  /**
+   * List all available probe ABIs.
+   */
+  QVector<ProbeABI> listProbeABIs();
 }
 
 }
